==> openshift-model-6.2.0-sources.jar: io/fabric8/openshift/api/model/GitBuildSourceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitBuildSourceFluentImpl<A extends GitBuildSourceFluent<A>> extends BaseFluent<A> implements GitBuildSourceFluent<A>{
  public GitBuildSourceFluentImpl() {
  }
  public GitBuildSourceFluentImpl(GitBuildSource instance) {
    this.withHttpProxy(instance.getHttpProxy()); 
    this.withHttpsProxy(instance.getHttpsProxy()); 
    this.withNoProxy(instance.getNoProxy()); 
    this.withRef(instance.getRef()); 
    this.withUri(instance.getUri()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String httpProxy;
  private String httpsProxy;
  private String noProxy;
  private String ref;
  private String uri;
  private Map<String,Object> additionalProperties;
  public String getHttpProxy() {
    return this.httpProxy;
  }
  public A withHttpProxy(String httpProxy) {
    this.httpProxy=httpProxy; return (A) this;
  }
  public Boolean hasHttpProxy() {
    return this.httpProxy != null;
  }
  public String getHttpsProxy() {
    return this.httpsProxy;
  }
  public A withHttpsProxy(String httpsProxy) {
    this.httpsProxy=httpsProxy; return (A) this;
  }
  public Boolean hasHttpsProxy() {
    return this.httpsProxy != null;
  }
  public String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  public String getRef() {
    return this.ref;
  }
  public A withRef(String ref) {
    this.ref=ref; return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitBuildSourceFluentImpl that = (GitBuildSourceFluentImpl) o;
    if (httpProxy != null ? !httpProxy.equals(that.httpProxy) :that.httpProxy != null) return false;
    if (httpsProxy != null ? !httpsProxy.equals(that.httpsProxy) :that.httpsProxy != null) return false;
    if (noProxy != null ? !noProxy.equals(that.noProxy) :that.noProxy != null) return false;
    if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
    if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpProxy,  httpsProxy,  noProxy,  ref,  uri,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpProxy != null) { sb.append("httpProxy:"); sb.append(httpProxy + ","); }
    if (httpsProxy != null) { sb.append("httpsProxy:"); sb.append(httpsProxy + ","); }
    if (noProxy != null) { sb.append("noProxy:"); sb.append(noProxy + ","); }
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/GitBuildSourceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitBuildSourceFluentImpl<A extends GitBuildSourceFluent<A>> extends BaseFluent<A> implements GitBuildSourceFluent<A>{
  public GitBuildSourceFluentImpl() {
  }
  public GitBuildSourceFluentImpl(GitBuildSource instance) {
    if (instance != null) {
      this.withHttpProxy(instance.getHttpProxy());
      this.withHttpsProxy(instance.getHttpsProxy());
      this.withNoProxy(instance.getNoProxy());
      this.withRef(instance.getRef());
      this.withUri(instance.getUri());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String httpProxy;
  private String httpsProxy;
  private String noProxy;
  private String ref;
  private String uri;
  private Map<String,Object> additionalProperties;
  public String getHttpProxy() {
    return this.httpProxy;
  }
  public A withHttpProxy(String httpProxy) {
    this.httpProxy=httpProxy; return (A) this;
  }
  public Boolean hasHttpProxy() {
    return this.httpProxy != null;
  }
  public String getHttpsProxy() {
    return this.httpsProxy;
  }
  public A withHttpsProxy(String httpsProxy) {
    this.httpsProxy=httpsProxy; return (A) this;
  }
  public Boolean hasHttpsProxy() {
    return this.httpsProxy != null;
  }
  public String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  public String getRef() {
    return this.ref;
  }
  public A withRef(String ref) {
    this.ref=ref; return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitBuildSourceFluentImpl that = (GitBuildSourceFluentImpl) o;
    if (!java.util.Objects.equals(httpProxy, that.httpProxy)) return false;

    if (!java.util.Objects.equals(httpsProxy, that.httpsProxy)) return false;

    if (!java.util.Objects.equals(noProxy, that.noProxy)) return false;

    if (!java.util.Objects.equals(ref, that.ref)) return false;

    if (!java.util.Objects.equals(uri, that.uri)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpProxy,  httpsProxy,  noProxy,  ref,  uri,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpProxy != null) { sb.append("httpProxy:"); sb.append(httpProxy + ","); }
    if (httpsProxy != null) { sb.append("httpsProxy:"); sb.append(httpsProxy + ","); }
    if (noProxy != null) { sb.append("noProxy:"); sb.append(noProxy + ","); }
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
